/* Copyright (c) 2012 Jesper Öqvist <jesper@llbit.se>
 *
 * This file is part of Chunky.
 *
 * Chunky is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Chunky is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Chunky.  If not, see <http://www.gnu.org/licenses/>.
 */
package se.llbit.chunky.renderer;

import java.text.DecimalFormat;

import org.apache.log4j.Logger;

/**
 * @author Jesper Öqvist <jesper@llbit.se>
 */
public class LoggingRenderListener implements RenderStatusListener {
	
	private static final Logger logger =
			Logger.getLogger(LoggingRenderListener.class);
	
	private final DecimalFormat decimalFormat;
	
	/**
	 * Constructor
	 */
	public LoggingRenderListener() {
		decimalFormat = new DecimalFormat();
		decimalFormat.setGroupingSize(3);
		decimalFormat.setGroupingUsed(true);
	}

	@Override
	public void setProgress(String task, int done, int start, int target) {
		logger.info(String.format("%s: %s of %s",
				task, decimalFormat.format(done), decimalFormat.format(target)));
	}
	
	@Override
	public void setProgress(String task, int done, int start, int target, String eta) {
		logger.info(String.format("%s: %s of %s",
				task, decimalFormat.format(done), decimalFormat.format(target)));
		logger.info("ETA: " + eta);
	}

	@Override
	public void chunksLoaded() {
	}

	@Override
	public void setRenderTime(long time) {
		int seconds = (int) ((time / 1000) % 60);
		int minutes = (int) ((time / 60000) % 60);
		int hours = (int) (time / 3600000);
		logger.info(String.format(
				"Render time: %d hours, %d minutes, %d seconds",
				hours, minutes, seconds));
	}

	@Override
	public void setSamplesPerSecond(int sps) {
		logger.info("SPS: " + decimalFormat.format(sps));
	}

	@Override
	public void setSPP(int spp) {
		logger.info("SPP: " + decimalFormat.format(spp));
	}

	@Override
	public void sceneSaved() {
	}

	@Override
	public void sceneLoaded() {
	}

	@Override
	public void renderStateChanged(boolean pathTrace, boolean paused) {
	}

}
